@@ -1,7 +1,7 @@
 package # hide from PAUSE 
     Lazy;
 
-use base 'DBIx::Class::Test::SQLite';
+use base 'DBIC::Test::SQLite';
 use strict;
 
 __PACKAGE__->set_table("Lazy");
@@ -12,14 +12,14 @@ __PACKAGE__->columns('horizon',   qw(eep orp));
 __PACKAGE__->columns('vertical',  qw(oop opop));
 
 sub create_sql {
-	return qq{
-		this INTEGER,
-		that INTEGER,
-		eep  INTEGER,
-		orp  INTEGER,
-		oop  INTEGER,
-		opop INTEGER
-	};
+  return qq{
+    this INTEGER,
+    that INTEGER,
+    eep  INTEGER,
+    orp  INTEGER,
+    oop  INTEGER,
+    opop INTEGER
+  };
 }
 
 1;
